--[[ Battle Pet Ability Tooltips

This small mod displays ability tooltips when you mouseover a pet during a pet battle.

The default UI will list each ability on a pet's tooltip and whether it's strong or weak against the current opponent. This goes a step further and displays exactly what each ability will do to its current opponent.

The primary use is for analyzing the abilities of an opponent's pets and their potential effect on your current pet. Though it can have some secondary use to see what effect your sidelined pets will have against the currently-active opponent pet.

09/02/17 1.0.10 toc update for 7.3 patch
07/16/16 1.0.9 toc update for 7.0 patch
06/22/15 1.0.8 toc update for 6.2 patch
02/23/15 1.0.7 toc update for 6.1 patch
01/17/15 1.0.6 belated toc update for 6.0 patch
09/11/13 1.0.5 toc update for 5.4 patch
05/12/13 1.0.4 toc update for 5.3 patch
12/12/12 1.0.3 initial release

]]

local tooltips = {}

local function init()
	for i=1,3 do
		table.insert(tooltips,CreateFrame("Frame",nil,PetBattlePrimaryUnitTooltip,"SharedPetBattleAbilityTooltipTemplate"))
	end
	PetBattlePrimaryUnitTooltip:HookScript("OnHide",function() for i=1,3 do tooltips[i]:Hide() end end)
end

local function list(self,owner,pet)
	local anchorTo = self
	local tooltip
	for ability=1,3 do
		tooltip = tooltips[ability]
		if C_PetBattles.GetAbilityInfo(owner,pet,ability) then
			PET_BATTLE_ABILITY_INFO.petOwner = owner
			PET_BATTLE_ABILITY_INFO.petIndex = pet
			PET_BATTLE_ABILITY_INFO.abilityID = nil
			PET_BATTLE_ABILITY_INFO.abilityIndex = ability
			SharedPetBattleAbilityTooltip_SetAbility(tooltip,PET_BATTLE_ABILITY_INFO)
			tooltip:ClearAllPoints()
			if ability>1 then
				tooltip:SetPoint("TOP",anchorTo,"BOTTOM")
			elseif owner==1 then
				tooltip:SetPoint("TOPLEFT",anchorTo,"TOPRIGHT")
			else
				tooltip:SetPoint("TOPRIGHT",anchorTo,"TOPLEFT")
			end
			tooltip:Show()
			anchorTo = tooltip
		else
			tooltip:Hide()
		end
	end
end

local frame = CreateFrame("Frame")
frame:SetScript("OnEvent",function(self,event,addon)
	if IsAddOnLoaded("Blizzard_PetBattleUI") then
		init()
		hooksecurefunc("PetBattleUnitTooltip_UpdateForUnit",list)
		self:UnregisterEvent("ADDON_LOADED")
	end
end)
frame:RegisterEvent("ADDON_LOADED")
